.. _prerequisites:

====================
System Prerequisites
====================

Git
---

If you do not have ``git`` already available and installed on your machine, follow the instruction
on `the official website <https://git-scm.com/book/en/v2/Getting-Started-Installing-Git>`_.

Docker & Docker compose
-----------------------

To install Docker and Docker compose follow the instruction on the official website.
The community edition (CE) is sufficient for using this plugin.

* Docker

https://docs.docker.com/install/

* Docker compose

https://docs.docker.com/compose/install/

It is also possible to install via ``pip`` ::

    $ pip install docker docker-compose

Once ``docker`` and ``docker-compose`` are installed, you are ready to install the
**Slicer Package Manager**.
